@@ -1,18 +1,24 @@
 #
-# Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 """
@@ -34,9 +40,6 @@ import subprocess
 
 import mysqlsh
 
-CR_SERVER_LOST = 2013
-ER_OPTION_PREVENTS_STATEMENT = 1290
-
 from mysql_gadgets import MIN_MYSQL_VERSION, MAX_MYSQL_VERSION
 from mysql_gadgets.exceptions import (GadgetCnxInfoError, GadgetCnxError,
                                       GadgetQueryError, GadgetServerError,
@@ -44,15 +47,20 @@ from mysql_gadgets.exceptions import (GadgetCnxInfoError, GadgetCnxError,
 from mysql_gadgets.common.connection_parser import (parse_connection,
                                                     hostname_is_ip,
                                                     clean_IPv6,)
-from mysql_gadgets.common.tools import (create_option_file, get_abs_path,
+from mysql_gadgets.common.logger import CustomLevelLogger
+from mysql_gadgets.common.tools import (get_abs_path,
                                         is_executable, run_subprocess,
                                         shell_quote)
 
+CR_SERVER_LOST = 2013
+ER_OPTION_PREVENTS_STATEMENT = 1290
+
 _FOREIGN_KEY_SET = "SET foreign_key_checks = {0}"
 _AUTOCOMMIT_SET = "SET AUTOCOMMIT = {0}"
 _GTID_ERROR = ("The server {host}:{port} does not comply to the latest GTID "
                "feature support. Errors:")
 
+logging.setLoggerClass(CustomLevelLogger)
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -82,7 +90,7 @@ def get_mysqld_version(mysqld_path):
     :return: tuple with with major, minor and release number and version string
     :rtype tuple((int, int, int), str)
     """
-    cmd = "{0} --version".format(shell_quote(mysqld_path))
+    cmd = u"{0} --version".format(shell_quote(mysqld_path))
     version_proc = run_subprocess(cmd,
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE, shell=False,
@@ -126,7 +134,6 @@ def is_valid_mysqld(mysqld_path):
                   mysqld_path)
     return False
 
-
 class MySQLUtilsCursorResult(object):
     def __init__(self, result):
         self._result = result
@@ -415,65 +422,13 @@ class Server(object):
         # Set to TRUE when foreign key checks are ON. Check with
         # foreign_key_checks_enabled.
         self.fkeys = None
-        self.autocommit = None
+        self.autocommit = True  # Set autocommit to True by default.
         self.read_only = False
         self.aliases = set()
         self.grants_enabled = None
         self._version = None
         self._version_full = None
 
-    @staticmethod
-    def to_config_file(server, section_name="client", prefix_dir=None):
-        """ Create a MySQL randomly named config file from an existing server
-        instance under prefix dir.
-        :param server:    instance object that must be instance of the Server
-                          class or a subclass.
-        :type  server:    Server or server subclass
-        :param section_name: name of the section on the config file under which
-                             we are going to add the key, value information
-                             of the server
-        :type section_name: str
-        :param prefix_dir: full path to a directory where we want the temporary
-                           file to be created. By default it uses the $HOME of
-                           the user.
-        :type prefix_dir: str
-        :return: string with full path to the created config file.
-        :rtype: str
-        :raises TypeError: if the server is neither a Server nor a subclass
-                           of a Server.
-        """
-        if isinstance(server, Server):
-            param_dict = server.get_connection_values()
-            # rename passwd key if exists to password
-            password = param_dict.get("passwd", None)
-            if password:
-                param_dict["password"] = password
-                param_dict.pop("passwd", None)
-            # Add --protocol=tcp if we are using a port
-            if "port" in param_dict:
-                param_dict["protocol"] = "tcp"
-
-            # On windows scape the \
-            if os.name == 'nt':
-                if "ssl_ca" in param_dict:
-                    param_dict["ssl_ca"] = param_dict["ssl_ca"].replace(
-                        "\\", "\\\\")
-                if "ssl_cert" in param_dict:
-                    param_dict["ssl_cert"] = param_dict["ssl_cert"].replace(
-                        "\\", "\\\\")
-                if "ssl_key" in param_dict:
-                    param_dict["ssl_key"] = param_dict["ssl_key"].replace(
-                        "\\", "\\\\")
-            # This ssl parameter is used internally on the server class
-            # and is not required in a configuration file.
-            if "ssl" in param_dict:
-                param_dict.pop("ssl")
-            return create_option_file({section_name: param_dict},
-                                      prefix_dir=prefix_dir)
-        else:
-            raise TypeError("The server argument's type is neither Server nor "
-                            "a subclass of Server")
-
     @classmethod
     def from_server(cls, server, conn_info=None):
         """ Create a new server instance from an existing one.
@@ -796,12 +751,6 @@ class Server(object):
         """
         try:
             self.db_conn = self.get_connection()
-            # If no charset provided, get it from the "character_set_client"
-            # server variable.
-            # if not self.charset:
-            #     res = self.show_server_variable('character_set_client')
-            #     self.db_conn.set_charset_collation(charset=res[0][1])
-            #     self.charset = res[0][1]
             if self.ssl:
                 res = self.exec_query("SHOW STATUS LIKE 'Ssl_cipher'")
                 if res[0][1] == '':
@@ -837,26 +786,30 @@ class Server(object):
                 parameters['socket'] = self.socket
             if self.passwd and self.passwd != "":
                 parameters['password'] = self.passwd
-            if self.charset:
-                parameters['charset'] = self.charset
             parameters['host'] = parameters['host'].replace("[", "")
             parameters['host'] = parameters['host'].replace("]", "")
 
             # Add SSL parameters ONLY if they are not None
             if self.ssl_ca is not None:
-                parameters['sslCa'] = self.ssl_ca
+                parameters['ssl-ca'] = self.ssl_ca
             if self.ssl_cert is not None:
-                parameters['sslCert'] = self.ssl_cert
+                parameters['ssl-cert'] = self.ssl_cert
             if self.ssl_key is not None:
-                parameters['sslKey'] = self.ssl_key
+                parameters['ssl-key'] = self.ssl_key
 
+            # The ca certificate is verified only if the ssl option is also
+            # specified.
+            if self.ssl and parameters['ssl-ca']:
+                parameters['ssl-mode'] = "VERIFY_CA"
+
+            if not parameters.has_key("ssl-mode"):
+                parameters['ssl-mode'] = "PREFERRED"
             db_conn = mysqlsh.mysql.get_classic_session(parameters)
             # Return MySQL connection object.
             return db_conn
         except mysqlsh.DBError as err:
-            _LOGGER.debug("Classic Session Error: %s", err)
-            raise GadgetCnxError(err.args[1], err.args[0], cause=err,
-                                 server=self)
+            _LOGGER.debug("Connector Error: %s", err)
+            raise GadgetCnxError(err.args[1], err.args[0], cause=err, server=self)
         except AttributeError as err:
             # Might be raised by mysql.connector.connect()
             raise GadgetCnxError(str(err), cause=err, server=self)
@@ -887,9 +840,10 @@ class Server(object):
                      By default: False.
         :type  full: boolean
 
-        :return: version string or None if an error occurs when trying to get
+        :return: List of version numbers(ints) if full = False or a string if
+                 full = True or None if an error occurs when trying to get
                  the version information from the server.
-        :rtype:  string or None
+        :rtype:  string or int list or None
         """
         # Return the local version value if already known.
         if self._version:
@@ -1013,6 +967,7 @@ class Server(object):
                 q_killer.start()
             # Execute query.
             cur = None
+
             if params == ():
                 if query_to_log:
                     _LOGGER.debug("MySQL query: %s", query_to_log)
@@ -1026,9 +981,7 @@ class Server(object):
                 else:
                     _LOGGER.debug("MySQL query: %s, params %s", query_str,
                                   params)
-                raise GadgetQueryError(
-                    "Execution with parameters not supported. Query: "
-                    "{0}".format(query_str), query_str)
+                cur = MySQLUtilsCursorResult(self.db_conn.run_sql(query_str, params))
         except mysqlsh.DBError as err:
             # if any exception happened, mask  the query_str that will be
             # shown in the exception messages
@@ -1090,7 +1043,7 @@ class Server(object):
             # No results (not a SELECT)
             try:
                 if do_commit:
-                    self.db_conn.commit()
+                    self.db_conn.run_sql("commit")
             except mysqlsh.DBError as err:
                 if query_to_log:
                     query_str = query_to_log
@@ -1111,7 +1064,7 @@ class Server(object):
             raise GadgetCnxError(
                 "You must call connect before commit.", server=self)
 
-        self.db_conn.commit()
+        self.db_conn.run_sql("commit")
 
     def rollback(self):
         """Perform a ROLLBACK.
@@ -1123,7 +1076,7 @@ class Server(object):
             raise GadgetCnxError(
                 "You must call connect before rollback.", server=self)
 
-        self.db_conn.rollback()
+        self.db_conn.run_sql("rollback")
 
     def show_server_variable(self, variable):
         """Get the variable information using SHOW VARIABLES statement.
@@ -1153,13 +1106,14 @@ class Server(object):
         :type  var_name: str
         :param var_value: value to which we want to set the variable.
         :type  var_value: str
-        :param var_type: Type of the variable ('session' or 'global'). By
-                         default session is used.
+        :param var_type: Type of the variable ('session', 'global', 'persist'
+                         'persist_only'). By default session is used.
         :type  var_type: str
         :raises GadgetDBError: if an invalid var_type is provided as argument.
         """
 
-        if var_type.lower() in ('global', 'session'):
+        if var_type.lower() in ('global', 'session', 'persist',
+                                'persist_only'):
             var_type = '{0}.'.format(var_type)  # Add dot (.)
         else:
             raise GadgetError("Invalid variable type: {0}. Supported types: "
@@ -1208,6 +1162,31 @@ class Server(object):
         res = self.exec_query("SELECT @@{0}{1}".format(var_type, var_name))
         return res[0][0]
 
+    def has_default_value(self, var_name):
+        """Check if the variable has the default value or was already change.
+
+        Return a boolean value indicating if the variable is set with the
+        compiled default value (true), or if it was already changed explicitly
+        by the user somehow (false), i.e. variable changed with the SET
+        statement, a command line option, or the configuration file.
+
+        NOTE: This method requires the performance_schema to be enabled.
+
+        :param var_name: Name of the target variable to check.
+        :type var_name: string
+        :return: True if the variable value is the compiled default one, or
+                 False otherwise (meaning that the variable value was already
+                 changed by the user).
+        :rtype: boolean
+        """
+        res = self.exec_query("SELECT variable_source "
+                              "FROM performance_schema.variables_info "
+                              "WHERE variable_name='{0}'".format(var_name))
+        if res[0][0] == 'COMPILED':
+            return True
+        else:
+            return False
+
     def flush_logs(self, log_type=None):
         """Execute the FLUSH [log_type] LOGS statement.
 
@@ -1383,7 +1362,7 @@ class Server(object):
                 if len(cmd) > 1:
                     if cmd[0] != '#':
                         if verbose:
-                            _LOGGER.debug(cmd)
+                            _LOGGER.debug("%s", cmd)
                         query_options = {
                             'fetch': False
                         }
@@ -1512,7 +1491,7 @@ class Server(object):
                 self.exec_query("SHOW GRANTS FOR 'snuffles'@'host'")
                 self.grants_enabled = True
             except (GadgetCnxError, GadgetQueryError) as err:
-                if (err.errno == ER_OPTION_PREVENTS_STATEMENT and
+                if (err.args[0] == ER_OPTION_PREVENTS_STATEMENT and
                         "--skip-grant-tables" in err.errmsg):
                     self.grants_enabled = False
                 # Ignore other errors as they are not pertinent to the check
@@ -1740,7 +1719,7 @@ class QueryKillerThread(threading.Thread):
 
         # Close connection.
         try:
-            self._connection.close()
+            self._connection.disconnect()
         except mysqlsh.DBError:
             # Only raise error if no previous error has occurred.
             if not connector_error:
