@@ -1,18 +1,24 @@
 #
-# Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 """
@@ -28,6 +34,7 @@ from mysql_gadgets.exceptions import (GadgetError,
                                       GadgetQueryError)
 from mysql_gadgets.common.connection_parser import (clean_IPv6,
                                                     parse_user_host,)
+from mysql_gadgets.common.logger import CustomLevelLogger
 from mysql_gadgets.common.sql_utils import (is_quoted_with_backticks,
                                             quote_with_backticks,)
 
@@ -35,6 +42,8 @@ from mysql_gadgets.common.sql_utils import (is_quoted_with_backticks,
 ERROR_USER_WITHOUT_PRIVILEGES = ("User '{user}' on '{host}@{port}' does not "
                                  "have sufficient privileges to "
                                  "{operation} (required: {req_privileges}).")
+
+logging.setLoggerClass(CustomLevelLogger)
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -248,7 +257,7 @@ class User(object):
             query_str += "'{0}'@'{1}' ".format(self.user, self.host)
 
         if self.verbosity > 0:
-            _LOGGER.debug(query_str)
+            _LOGGER.debug("%s", query_str)
 
         try:
             self.server1.exec_query(query_str, self.query_options)
@@ -273,7 +282,7 @@ class User(object):
             user, host = parse_user_host(user_name)
 
         res = self.server1.exec_query("SELECT * FROM mysql.user "
-                                      "WHERE user = %s and host = %s",
+                                      "WHERE user = ? and host = ?",
                                       {'params': (user, host)})
 
         return res is not None and len(res) >= 1
