@@ -1,6 +1,13 @@
 // Assumptions: ensure_schema_does_not_exist is available
 // Assumes __uripwd is defined as <user>:<pwd>@<host>:<plugin_port>
 // validateMember and validateNotMember are defined on the setup script
+testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname});
+// ensure my.cnf file is saved/restored for replay in recording mode
+testutil.snapshotSandboxConf(__mysql_sandbox_port1);
+testutil.deploySandbox(__mysql_sandbox_port2, "root", {report_host: hostname});
+testutil.snapshotSandboxConf(__mysql_sandbox_port2);
+
+shell.connect("mysql://root:root@localhost:" + __mysql_sandbox_port1);
 
 //@ Session: validating members
 var members = dir(dba);
@@ -13,26 +20,34 @@ validateMember(members, 'dropMetadataSchema');
 validateMember(members, 'getCluster');
 validateMember(members, 'help');
 validateMember(members, 'killSandboxInstance');
-validateMember(members, 'resetSession');
 validateMember(members, 'startSandboxInstance');
 validateMember(members, 'checkInstanceConfiguration');
 validateMember(members, 'stopSandboxInstance');
+validateMember(members, 'configureInstance');
 validateMember(members, 'configureLocalInstance');
 validateMember(members, 'verbose');
 validateMember(members, 'rebootClusterFromCompleteOutage');
 
 //@# Dba: createCluster errors
-var c1 = dba.createCluster();
-var c1 = dba.createCluster(5);
-var c1 = dba.createCluster('', 5);
-var c1 = dba.createCluster('devCluster', 'bla');
-var c1 = dba.createCluster('devCluster', {invalid:1, another:2});
-var c1 = dba.createCluster('devCluster', {memberSslMode: 'foo'});
-var c1 = dba.createCluster('devCluster', {memberSslMode: ''});
-var c1 = dba.createCluster('devCluster', {adoptFromGR: true, memberSslMode: 'AUTO'});
-var c1 = dba.createCluster('devCluster', {adoptFromGR: true, memberSslMode: 'REQUIRED'});
-var c1 = dba.createCluster('devCluster', {adoptFromGR: true, memberSslMode: 'DISABLED'});
-var c1 = dba.createCluster('devCluster', {ipWhitelist: " "});
+dba.createCluster();
+dba.createCluster(5);
+dba.createCluster('');
+dba.createCluster('', 5);
+dba.createCluster('devCluster', 'bla');
+dba.createCluster('devCluster', {invalid:1, another:2});
+dba.createCluster('devCluster', {memberSslMode: 'foo'});
+dba.createCluster('devCluster', {memberSslMode: ''});
+dba.createCluster('devCluster', {adoptFromGR: true, memberSslMode: 'AUTO'});
+dba.createCluster('devCluster', {adoptFromGR: true, memberSslMode: 'REQUIRED'});
+dba.createCluster('devCluster', {adoptFromGR: true, memberSslMode: 'DISABLED'});
+dba.createCluster('devCluster', {adoptFromGR: true, multiPrimary: true, force: true});
+dba.createCluster('devCluster', {adoptFromGR: true, multiPrimary: false});
+dba.createCluster('devCluster', {adoptFromGR: true, multiMaster: true, force: true});
+dba.createCluster('devCluster', {adoptFromGR: true, multiMaster: false});
+dba.createCluster('devCluster', {multiPrimary:false, multiMaster: false});
+dba.createCluster('devCluster', {multiPrimary:true, multiMaster: false});
+dba.createCluster('devCluster', {ipWhitelist: " "});
+dba.createCluster('1invalidN4me');
 
 
 //@ Dba: createCluster with ANSI_QUOTES success
@@ -49,7 +64,7 @@ print("Current sql_mode is: "+ row[0] + "\n");
 if (__have_ssl)
     var c1 = dba.createCluster('devCluster', {memberSslMode: 'REQUIRED'});
 else
-    var c1 = dba.createCluster('devCluster');
+    var c1 = dba.createCluster('devCluster', {memberSslMode: 'DISABLED'});
 print(c1);
 
 //@ Dba: dissolve cluster created with ansi_quotes and restore original sql_mode
@@ -80,49 +95,49 @@ print(c1)
 //@# Dba: createCluster already exist
 var c1 = dba.createCluster('devCluster');
 
-// TODO: add multi-master unit-tests
-
 //@# Dba: checkInstanceConfiguration errors
-dba.checkInstanceConfiguration('localhost:' + __mysql_sandbox_port1);
+dba.checkInstanceConfiguration('root@localhost:' + __mysql_sandbox_port1);
 dba.checkInstanceConfiguration('sample@localhost:' + __mysql_sandbox_port1);
-var result = dba.checkInstanceConfiguration('root:root@localhost:' + __mysql_sandbox_port1);
+dba.checkInstanceConfiguration('root:root@localhost:' + __mysql_sandbox_port1);
 
 //@ Dba: checkInstanceConfiguration ok1
 var uri2 = 'root:root@localhost:' + __mysql_sandbox_port2;
-var result = dba.checkInstanceConfiguration(uri2);
-print (result.status)
+dba.checkInstanceConfiguration(uri2);
 
 //@ Dba: checkInstanceConfiguration ok2
-var result = dba.checkInstanceConfiguration('root@localhost:' + __mysql_sandbox_port2, {password:'root'});
-print (result.status)
-
-//@ Dba: checkInstanceConfiguration ok3
-var result = dba.checkInstanceConfiguration('root@localhost:' + __mysql_sandbox_port2, {dbPassword:'root'});
-print (result.status)
+dba.checkInstanceConfiguration('root@localhost:' + __mysql_sandbox_port2, {PASSWORD:'root'});
 
 //@<OUT> Dba: checkInstanceConfiguration report with errors
 dba.checkInstanceConfiguration(uri2, {mycnfPath:'mybad.cnf'});
 
+// Delete the config file so that configureLocal doesn't detect it as a sandbox and auto-picks the config file
+// This test should actually be rewritten to use raw sandboxes, but no time for that at this moment
+var mycnf1_path = testutil.getSandboxConfPath(__mysql_sandbox_port1);
+testutil.cpfile(mycnf1_path, mycnf1_path+".bak");
+testutil.rmfile(mycnf1_path);
+
 //@# Dba: configureLocalInstance errors
-dba.configureLocalInstance('someotherhost:' + __mysql_sandbox_port1);
-dba.configureLocalInstance('localhost:' + __mysql_sandbox_port1);
+// TODO: This test needs an actual remote instance
+//dba.configureLocalInstance('sample:@someotherhost:' + __mysql_sandbox_port1);
+dba.configureLocalInstance('root@localhost:' + __mysql_sandbox_port1);
 dba.configureLocalInstance('sample@localhost:' + __mysql_sandbox_port1);
+//@# Dba: configureLocalInstance errors 5.7 {VER(<8.0.11)}
 dba.configureLocalInstance('root@localhost:' + __mysql_sandbox_port1, {password:'root'});
+//@# Dba: configureLocalInstance errors 8.0 {VER(>=8.0.11)}
+dba.configureLocalInstance('root@localhost:' + __mysql_sandbox_port1, {password:'root'});
+
+// Restore config file
+testutil.cpfile(mycnf1_path + ".bak", mycnf1_path);
+testutil.rmfile(mycnf1_path + ".bak");
 
 //@<OUT> Dba: configureLocalInstance updating config file
 dba.configureLocalInstance(uri2, {mycnfPath:'mybad.cnf'});
 
 //@ Dba: configureLocalInstance report fixed 1
-var result = dba.configureLocalInstance(uri2, {mycnfPath:'mybad.cnf'});
-print (result.status)
+dba.configureLocalInstance(uri2, {mycnfPath:'mybad.cnf'});
 
 //@ Dba: configureLocalInstance report fixed 2
-var result = dba.configureLocalInstance('root@localhost:' + __mysql_sandbox_port2, {mycnfPath:'mybad.cnf', password:'root'});
-print (result.status)
-
-//@ Dba: configureLocalInstance report fixed 3
-var result = dba.configureLocalInstance('root@localhost:' + __mysql_sandbox_port2, {mycnfPath:'mybad.cnf', dbPassword:'root'});
-print (result.status)
+dba.configureLocalInstance('root@localhost:' + __mysql_sandbox_port2, {mycnfPath:'mybad.cnf', password:'root'});
 
 //@ Dba: Create user without all necessary privileges
 // create user that has all permissions to admin a cluster but doesn't have
@@ -141,7 +156,7 @@ var row = result.fetchOne();
 print("Number of accounts: "+ row[0] + "\n");
 session.close();
 
-//@ Dba: configureLocalInstance not enough privileges
+//@# Dba: configureLocalInstance not enough privileges
 // Regression for BUG#25614855 : CONFIGURELOCALINSTANCE URI USER WITHOUT
 // PERMISSIONS, CREATES A WRONG NEW USER
 dba.configureLocalInstance('missingprivileges:@localhost:' + __mysql_sandbox_port2,
@@ -188,7 +203,7 @@ dba.configureLocalInstance('mydba:@localhost:' + __mysql_sandbox_port2,
 //@<OUT> Dba: configureLocalInstance create existing valid admin user
 // Regression for BUG#25519190 : CONFIGURELOCALINSTANCE() FAILS UNGRACEFUL IF CALLED TWICE
 dba.configureLocalInstance('mydba:@localhost:' + __mysql_sandbox_port2,
-    {clusterAdmin: "dba_test", clusterAdminPassword:"",
+    {clusterAdmin: "dba_test",
         mycnfPath:__sandbox_dir + __mysql_sandbox_port2 + __path_splitter + 'my.cnf'});
 
 //@ Dba: remove needed privilege (REPLICATION SLAVE) from created admin user
@@ -198,10 +213,10 @@ session.runSql("REVOKE REPLICATION SLAVE ON *.* FROM 'dba_test'@'%'");
 session.runSql("SET SQL_LOG_BIN=1");
 session.close();
 
-//@ Dba: configureLocalInstance create existing invalid admin user
+//@# Dba: configureLocalInstance create existing invalid admin user
 // Regression for BUG#25519190 : CONFIGURELOCALINSTANCE() FAILS UNGRACEFUL IF CALLED TWICE
 dba.configureLocalInstance('mydba:@localhost:' + __mysql_sandbox_port2,
-    {clusterAdmin: "dba_test", clusterAdminPassword:"",
+    {clusterAdmin: "dba_test",
         mycnfPath:__sandbox_dir + __mysql_sandbox_port2 + __path_splitter + 'my.cnf'});
 
 //@ Dba: Delete previously create an admin user with all needed privileges
@@ -216,19 +231,45 @@ var row = result.fetchOne();
 print("Number of 'mydba'@'localhost' accounts: "+ row[0] + "\n");
 session.close();
 
+connect_to_sandbox([__mysql_sandbox_port2]);
+// Create account without global grant option
+session.runSql("SET sql_log_bin = 0");
+session.runSql("CREATE USER 'no_global_grant'@'%'");
+session.runSql("GRANT ALL PRIVILEGES on *.* to 'no_global_grant'@'%'");
+session.runSql("SET sql_log_bin = 1");
+session.close();
+
+//@ configureLocalInstance() should fail if user does not have global GRANT OPTION
+dba.configureLocalInstance({host: localhost, port: __mysql_sandbox_port2, user: 'no_global_grant', password:''});
+
+shell.connect({scheme:'mysql', host: localhost, port: __mysql_sandbox_port2, user: 'no_global_grant', password: ''});
+
+//@ createCluster() should fail if user does not have global GRANT OPTION
+dba.createCluster("cluster");
+
+session.close();
+
+connect_to_sandbox([__mysql_sandbox_port2]);
+// Drop user
+session.runSql("SET sql_log_bin = 0");
+session.runSql("DROP user 'no_global_grant'@'%'");
+session.runSql("SET sql_log_bin = 1");
+session.close();
+
 connect_to_sandbox([__mysql_sandbox_port1]);
 
 //@# Dba: getCluster errors
 var c2 = dba.getCluster();
 var c2 = dba.getCluster(5);
+var c2 = dba.getCluster('', {}, 5);
 var c2 = dba.getCluster('', 5);
 var c2 = dba.getCluster('');
 var c2 = dba.getCluster('#');
 var c2 = dba.getCluster("over40chars_12345678901234567890123456789");
 var c2 = dba.getCluster('devCluster');
-var c2 = dba.getCluster('devCluster');
 
 //@ Dba: getCluster
 print(c2);
 
-session.close();
+testutil.destroySandbox(__mysql_sandbox_port1);
+testutil.destroySandbox(__mysql_sandbox_port2);
