@@ -1,10 +1,14 @@
 //@ Result member validation
+|affectedItemsCount: OK|
 |executionTime: OK|
 |warningCount: OK|
 |warnings: OK|
+|warningsCount: OK|
+|getAffectedItemsCount: OK|
 |getExecutionTime: OK|
 |getWarningCount: OK|
 |getWarnings: OK|
+|getWarningsCount: OK|
 |columnCount: OK|
 |columnNames: OK|
 |columns: OK|
@@ -17,6 +21,7 @@
 |fetchAll: OK|
 |hasData: OK|
 |nextDataSet: OK|
+|nextResult: OK|
 |affectedRowCount: OK|
 |autoIncrementValue: OK|
 |getAffectedRowCount: OK|
@@ -63,4 +68,15 @@
 // Resultset property access
 |Name with property: jack|
 |Age with property: 17|
-|Unable to get length with property: 4|
\ No newline at end of file
+|Unable to get length with property: 4|
+
+//@<OUT> Resultset row as objects
+Alias with property: jack
+Age as item: 17
+
+{
+    "age": 17, 
+    "alias": "jack", 
+    "length": 17
+}
+
