@@ -5,8 +5,8 @@ usr = shell.prompt("Username: ", {'defaultValue': "mike"})
 pwd = shell.prompt("Password: ", {'type': "password"})
 
 # Connect to MySQL Server on a network machine
-mySession = mysqlx.get_node_session( {
+mySession = mysqlx.get_session( {
         'host': 'localhost', 'port': 33060,
-        'dbUser': usr, 'dbPassword': pwd} )
+        'user': usr, 'password': pwd} )
 
 myDb = mySession.get_schema('test')
