@@ -10,14 +10,12 @@ def print_result(res):
       for column in columns:
         print "%s: %s \n" % (column.get_column_name(), record[index])
         index = index + 1
-        
+      
       # Get the next record
       record = res.fetch_one()
-      
   else:
     #INSERT, UPDATE, DELETE, ...
-    print 'Rows affected: %s' % res.get_affected_row_count()
-    
+    print 'Rows affected: %s' % res.get_affected_items_count()
 
-print_result(nodeSession.sql('DELETE FROM users WHERE age > 40').execute())
-print_result(nodeSession.sql('SELECT * FROM users WHERE age = 40').execute())
+print_result(mySession.sql('DELETE FROM users WHERE age > 40').execute())
+print_result(mySession.sql('SELECT * FROM users WHERE age = 40').execute())
