@@ -1,11 +1,10 @@
 # Connecting to MySQL Server and working with a Collection
-
 from mysqlsh import mysqlx
 
 # Connect to server
-mySession = mysqlx.get_node_session( {
+mySession = mysqlx.get_session( {
 'host': 'localhost', 'port': 33060,
-'dbUser': 'mike', 'dbPassword': 's3cr3t!'} )
+'user': 'mike', 'password': 'paSSw0rd'} )
 
 myDb = mySession.get_schema('test')
 
@@ -13,9 +12,9 @@ myDb = mySession.get_schema('test')
 myColl = myDb.create_collection('my_collection')
 
 # Insert documents
-myColl.add({'name': 'Sakila', 'age': 15}).execute()
-myColl.add({'name': 'Susanne', 'age': 24}).execute()
-myColl.add({'name': 'Mike', 'age': 39}).execute()
+myColl.add({'_id': '1', 'name': 'Sakila', 'age': 15}).execute()
+myColl.add({'_id': '2', 'name': 'Susanne', 'age': 24}).execute()
+myColl.add({'_id': '3', 'name': 'Mike', 'age': 39}).execute()
 
 # Find a document
 docs = myColl.find('name like :param1 AND age < :param2') \
@@ -29,4 +28,4 @@ doc = docs.fetch_one()
 print doc
 
 # Drop the collection
-session.drop_collection('test','my_collection')
+myDb.drop_collection('my_collection')
