@@ -2,9 +2,9 @@
 from mysqlsh import mysqlx
 
 # Connect to server using a connection URL
-mySession = mysqlx.get_node_session( {
+mySession = mysqlx.get_session( {
   'host': 'localhost', 'port': 33060,
-  'dbUser': 'mike', 'dbPassword': 's3cr3t!'} )
+  'user': 'mike', 'password': 'paSSw0rd'} )
 
 myDb = mySession.get_schema('test')
 
